aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/kubatech/api/eig/EIGMode.java
diff options
context:
space:
mode:
authorNotAPenguin <michiel.vandeginste@gmail.com>2024-09-02 23:17:17 +0200
committerGitHub <noreply@github.com>2024-09-02 23:17:17 +0200
commit1b820de08a05070909a267e17f033fcf58ac8710 (patch)
tree02831a025986a06b20f87e5bcc69d1e0c639a342 /src/main/java/kubatech/api/eig/EIGMode.java
parentafd3fd92b6a6ab9ab0d0dc3214e6bc8ff7a86c9b (diff)
downloadGT5-Unofficial-1b820de08a05070909a267e17f033fcf58ac8710.tar.gz
GT5-Unofficial-1b820de08a05070909a267e17f033fcf58ac8710.tar.bz2
GT5-Unofficial-1b820de08a05070909a267e17f033fcf58ac8710.zip
The Great Renaming (#3014)
* move kekztech to a single root dir * move detrav to a single root dir * move gtnh-lanthanides to a single root dir * move tectech and delete some gross reflection in gt++ * remove more reflection inside gt5u * delete more reflection in gt++ * fix imports * move bartworks and bwcrossmod * fix proxies * move galactigreg and ggfab * move gtneioreplugin * try to fix gt++ bee loader * apply the rename rules to BW * apply rename rules to bwcrossmod * apply rename rules to detrav scanner mod * apply rename rules to galacticgreg * apply rename rules to ggfab * apply rename rules to goodgenerator * apply rename rules to gtnh-lanthanides * apply rename rules to gt++ * apply rename rules to kekztech * apply rename rules to kubatech * apply rename rules to tectech * apply rename rules to gt apply the rename rules to gt * fix tt import * fix mui hopefully * fix coremod except intergalactic * rename assline recipe class * fix a class name i stumbled on * rename StructureUtility to GTStructureUtility to prevent conflict with structurelib * temporary rename of GTTooltipDataCache to old name * fix gt client/server proxy names
Diffstat (limited to 'src/main/java/kubatech/api/eig/EIGMode.java')
-rw-r--r--src/main/java/kubatech/api/eig/EIGMode.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/main/java/kubatech/api/eig/EIGMode.java b/src/main/java/kubatech/api/eig/EIGMode.java
index 68ad633773..b3ebddff1b 100644
--- a/src/main/java/kubatech/api/eig/EIGMode.java
+++ b/src/main/java/kubatech/api/eig/EIGMode.java
@@ -10,8 +10,8 @@ import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;
-import gregtech.api.util.GT_Multiblock_Tooltip_Builder;
-import kubatech.tileentity.gregtech.multiblock.GT_MetaTileEntity_ExtremeIndustrialGreenhouse;
+import gregtech.api.util.MultiblockTooltipBuilder;
+import kubatech.tileentity.gregtech.multiblock.MTEExtremeIndustrialGreenhouse;
public abstract class EIGMode {
@@ -37,7 +37,7 @@ public abstract class EIGMode {
public abstract double getFertilizerBoost();
- public abstract GT_Multiblock_Tooltip_Builder addTooltipInfo(GT_Multiblock_Tooltip_Builder builder);
+ public abstract MultiblockTooltipBuilder addTooltipInfo(MultiblockTooltipBuilder builder);
/**
* Used to resolve factory type to an identifier.
@@ -98,15 +98,15 @@ public abstract class EIGMode {
/**
* Attempts to create a new bucket from a given item. Returns if the item cannot be inserted into the EIG.
*
* @see IEIGBucketFactory#tryCreateBucket(GT_MetaTileEntity_ExtremeIndustrialGreenhouse, ItemStack)
* @param greenhouse The {@link GT_MetaTileEntity_ExtremeIndustrialGreenhouse} that will contain the seed.
* @param input The {@link ItemStack} for the input item.
* @param maxConsume The maximum amount of items to consume.
* @param simulate Whether to actually consume the seed.
* @return Null if no bucket could be created from the item.
*/
- public EIGBucket tryCreateNewBucket(GT_MetaTileEntity_ExtremeIndustrialGreenhouse greenhouse, ItemStack input,
- int maxConsume, boolean simulate) {
+ public EIGBucket tryCreateNewBucket(MTEExtremeIndustrialGreenhouse greenhouse, ItemStack input, int maxConsume,
+ boolean simulate) {
// Validate inputs
if (input == null) return null;
maxConsume = Math.min(input.stackSize, maxConsume);
@@ -98,15 +98,15 @@ public abstract class EIGMode {
* Attempts to create a new bucket from a given item. Returns if the item cannot be inserted into the EIG.
*
- * @see IEIGBucketFactory#tryCreateBucket(GT_MetaTileEntity_ExtremeIndustrialGreenhouse, ItemStack)
- * @param greenhouse The {@link GT_MetaTileEntity_ExtremeIndustrialGreenhouse} that will contain the seed.
+ * @see IEIGBucketFactory#tryCreateBucket(MTEExtremeIndustrialGreenhouse, ItemStack)
+ * @param greenhouse The {@link MTEExtremeIndustrialGreenhouse} that will contain the seed.
* @param input The {@link ItemStack} for the input item.
* @param maxConsume The maximum amount of items to consume.